//
// MultiTest by Bryan Duke, http://www.acceleroto.com
// --this is a simple test app that contains a UIWebView in a Cocos2d layer (using iPhone 0.7.3) 
// --built: 2090712
//
// This code may be used & redistributed as outlined in the Cocos2D iPhone license

#import "LayerGame.h"
#import "LayerMenu.h"
#import "ccMacros.h"

@implementation LayerGame

-(id) init
{
	if( ! [super init] )
		return nil;

	isTouchEnabled = YES;
	isAccelerometerEnabled = YES;

	//default accelerometer from cocos2d skeleton
	[[UIAccelerometer sharedAccelerometer] setUpdateInterval:(1.0 / 60.0)];
	
	//add game variables here
	touchCounter = 1;
	
	//set up some pre-defined locations for the test sprites
	sprite1Position = CGPointMake(100.0f, 100.0f);
	sprite2Position = CGPointMake(300.0f, 200.0f);
	sprite3Position = CGPointMake(200.0f, 150.0f);


	//create the background image
	Sprite *background = [Sprite spriteWithFile:@"game_background.png"];
	background.position = CGPointMake(240.0f, 160.0f);
	[self addChild:background z:0];

	//set 16 bit textures
	[Texture2D setDefaultAlphaPixelFormat:kTexture2DPixelFormat_RGBA4444];

	Sprite *quit = [Sprite spriteWithFile:@"quit.png"];
	quit.position = CGPointMake(240.0f, 20.0f);
	[self addChild:quit z:0];
	
	
	//build some sprites just to move around the screen
	Sprite *sprite1 = [Sprite spriteWithFile:@"smile.png"];
	sprite1.position = CGPointMake(240.0f, 160.0f);
	sprite1.scale = 0.5f;
	[self addChild:sprite1 z:0 tag:1];
	
	Sprite *sprite2 = [Sprite spriteWithFile:@"smile.png"];
	sprite2.position = CGPointMake(240.0f, 160.0f);
	sprite2.scale = 0.5f;
	[self addChild:sprite2 z:0 tag:2];
	
	Sprite *sprite3 = [Sprite spriteWithFile:@"smile.png"];
	sprite3.position = CGPointMake(240.0f, 160.0f);
	sprite3.scale = 0.5f;
	[self addChild:sprite3 z:0 tag:3];
	
	
	
	[self schedule: @selector(step:) interval: 1.0 / 60.0];

	return self;
}

-(void) onEnter
{
	//this gets called after init() is run
	[super onEnter];

}

-(void) onExit
{

	[super onExit];
	[super stopAllActions];
}

-(void) step: (ccTime) delta
{
	//MAIN LOOP
	
	Sprite *sprite1 = (Sprite *)[self getChildByTag:1];
	Sprite *sprite2 = (Sprite *)[self getChildByTag:2];
	Sprite *sprite3 = (Sprite *)[self getChildByTag:3];

	
	//make sure each position is still on the screen (quick hack)
	float rightBorder = 480.0f;
	float leftBorder = 0.0f;
	float topBorder = 320.0f;
	float bottomBorder = 0.0f;
	float spriteRadius = 32.0f;
	//1st sprite bounds check
	if(sprite1Position.x > rightBorder - spriteRadius) sprite1Position.x = rightBorder - spriteRadius;
	else if(sprite1Position.x < leftBorder + spriteRadius) sprite1Position.x = leftBorder + spriteRadius;
	if(sprite1Position.y > topBorder - spriteRadius) sprite1Position.y = topBorder - spriteRadius;
	else if(sprite1Position.y < bottomBorder + spriteRadius) sprite1Position.y = bottomBorder + spriteRadius;
	//2nd sprite bounds check
	if(sprite2Position.x > rightBorder - spriteRadius) sprite2Position.x = rightBorder - spriteRadius;
	else if(sprite2Position.x < leftBorder + spriteRadius) sprite2Position.x = leftBorder + spriteRadius;
	if(sprite2Position.y > topBorder - spriteRadius) sprite2Position.y = topBorder - spriteRadius;
	else if(sprite2Position.y < bottomBorder + spriteRadius) sprite2Position.y = bottomBorder + spriteRadius;
	//3rd sprite bounds check
	if(sprite3Position.x > rightBorder - spriteRadius) sprite3Position.x = rightBorder - spriteRadius;
	else if(sprite3Position.x < leftBorder + spriteRadius) sprite3Position.x = leftBorder + spriteRadius;
	if(sprite3Position.y > topBorder - spriteRadius) sprite3Position.y = topBorder - spriteRadius;
	else if(sprite3Position.y < bottomBorder + spriteRadius) sprite3Position.y = bottomBorder + spriteRadius;
	
	//update the location for each sprite
	sprite1.position = sprite1Position;
	sprite2.position = sprite2Position;
	sprite3.position = sprite3Position;

	//clean house	
	sprite1 = nil;
	sprite2 = nil;
	sprite3 = nil;
}

#pragma mark -
#pragma mark touches methods
- (BOOL)ccTouchesBegan:(NSSet *)touches withEvent:(UIEvent *)event
{
	BOOL didTheEventGetHandled = NO; //keeps track of whether or not the method handled the touch event

	for (UITouch *touch in touches) {
		didTheEventGetHandled = YES; //set the event handled flag
		
		//cycle through the touch counter to step through which sprite we update
		touchCounter++;
		if (touchCounter > 3) touchCounter = 1;

		CGPoint location = [touch locationInView: [touch view]];
		//x & y are oriented in portrait mode for the phone
		//so, in the game, x is up & down and y is left & right.
		if (location.y > 225 && location.y < 255 && location.x < 35) { //tap in the bottom middle
			//go to the main menu
			Scene *s2 = [Scene node];
			[s2 addChild: [LayerMenu node]];
			[[Director sharedDirector] replaceScene: [FadeTransition transitionWithDuration:0.5f scene:s2 withColorRGB:0xffffff]];
			
		}
		else {
			//assign the touch to whatever corresponding sprite
			if (touchCounter == 1) sprite1Position = CGPointMake(location.y, location.x);
			else if (touchCounter == 2) sprite2Position = CGPointMake(location.y, location.x);
			else if (touchCounter == 3) sprite3Position = CGPointMake(location.y, location.x);
		}
	} //for loop

	//return the appropriate value depending on if the event got handled
	if(didTheEventGetHandled) return kEventHandled;
	else return kEventIgnored;
}

- (BOOL)ccTouchesMoved:(NSSet *)touches withEvent:(UIEvent *)event {
	//only touches that move are in touches
	//to cycle through all current touches, get them from event
	
	NSSet *allTouches = [event allTouches];  // <--this gets all the current touches

	for (UITouch *touch in allTouches) { //iterate through all the touches currently on the device
		CGPoint location = [touch locationInView: [touch view]]; //location of this touch

		//calculate the distance from this touch to all the sprites & update the sprite location if the touch is very close to the sprite location
		float touchDistanceToSprite;

		//this logic is just for test purposes...
		//NOTE: x & y are flipped between touches & the screen because of landscape mode
		touchDistanceToSprite = [self distanceBetweenTwoPoints: CGPointMake(location.y, location.x) toPoint:sprite1Position];
		if (touchDistanceToSprite < 40) sprite1Position = CGPointMake(location.y, location.x);

		touchDistanceToSprite = [self distanceBetweenTwoPoints:CGPointMake(location.y, location.x) toPoint:sprite2Position];
		if (touchDistanceToSprite < 40) sprite2Position =  CGPointMake(location.y, location.x);

		touchDistanceToSprite = [self distanceBetweenTwoPoints:CGPointMake(location.y, location.x) toPoint:sprite3Position];
		if (touchDistanceToSprite < 40) sprite3Position =  CGPointMake(location.y, location.x);

	}

	return 1;

}

- (BOOL)ccTouchesEnded:(NSSet *)touches withEvent:(UIEvent *)event
{

	return 1;
	
}

- (BOOL)ccTouchesCancelled:(NSSet *)touches withEvent:(UIEvent *)event {

	return 1;
	
}


- (void)accelerometer:(UIAccelerometer*)accelerometer didAccelerate:(UIAcceleration*)acceleration
{
	
	static float prevX=0, prevY=0;
//	static float prevX=0, prevY=0, prevZ=0;
	
	//Apple's basic accelerometer filter
	//NOTE: this is not good enough to use in a game 
#define kFilterFactor 0.05
	float accelX = acceleration.x * kFilterFactor + (1- kFilterFactor)*prevX;
	float accelY = acceleration.y * kFilterFactor + (1- kFilterFactor)*prevY;
//		float accelZ = acceleration.z * kFilterFactor + (1- kFilterFactor)*prevZ;
	
	//just for fun, move the sprites around with the accelerometer
	sprite1Position = CGPointMake(sprite1Position.x - 300 * accelY, sprite1Position.y + 300 * accelX);//the accelerometers don't change coordinates even though landscape mode makes our screen coordinate axis change
	sprite2Position = CGPointMake(sprite2Position.x - 150 * accelY, sprite2Position.y + 150 * accelX);
	sprite3Position = CGPointMake(sprite3Position.x - 200 * accelY, sprite3Position.y + 200 * accelX);
	
	
}


- (CGFloat)distanceBetweenTwoPoints:(CGPoint)fromPoint toPoint:(CGPoint)toPoint {
	float x = toPoint.x - fromPoint.x;
    float y = toPoint.y - fromPoint.y;
    
    return sqrt(x * x + y * y);
}

-(void) dealloc
{
	[super dealloc];
}
@end
