//
// MultiTest by Bryan Duke, http://www.acceleroto.com
// --this is a simple test app that contains a UIWebView in a Cocos2d layer (using iPhone 0.7.3) 
// --built: 2090712
//
// This code may be used & redistributed as outlined in the Cocos2D iPhone license

#import "LayerWebView.h"
#import "LayerMenu.h"

@implementation LayerWebView 

@synthesize toolbar;

-(id) init
{
	[super init];

	isTouchEnabled = YES;
	
	webViewLoadCounter = 0;
	
	// create view
	view = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 320, 480)];

	// create webView
	webView = [[UIWebView alloc] initWithFrame:CGRectMake(0, 0, 320, 436)];
		
	// Set Delegate so we can access UIWebViews methods
	webView.delegate = self;

	//load a default image into the web view
	NSBundle *bundle = [NSBundle mainBundle]; 
	NSString *path = [bundle bundlePath];
	NSString *fullPath = [NSBundle pathForResource:@"loading" ofType:@"png" inDirectory:path];
	[webView loadRequest:[NSURLRequest requestWithURL:[NSURL fileURLWithPath:fullPath]]];
	[webView setUserInteractionEnabled:NO]; //don't let the user scroll while things are loading
	
	// add the webView to the view
	[view addSubview:webView];

	//create a tool bar for the bottom of the screen to hold the back button
	toolbar = [UIToolbar new];
	[toolbar setFrame:CGRectMake(0, 436, 320, 44)];
	toolbar.barStyle = UIBarStyleBlackOpaque;

	//Create a button
	backButton = [[UIBarButtonItem alloc] initWithTitle:@"Return to the main menu" style:UIBarButtonItemStyleBordered target:self action:@selector(backClicked:)];

	[toolbar setItems:[NSArray arrayWithObjects:backButton,nil] animated:YES];
	[view addSubview:toolbar];
	[toolbar release];

	// add the view to the director
	[[[Director sharedDirector] openGLView] addSubview:view];
		
	return self;
}

- (void)webViewDidStartLoad:(UIWebView *)thisWebView {
	[[Director sharedDirector] setLandscape: NO];

}

- (void)webViewDidFinishLoad:(UIWebView *)thisWebView{
	//NOTE: the first load is just the background image.
	
	//increment a counter to keep track of how many pages have been loaded
	webViewLoadCounter++;

	if (webViewLoadCounter == 1) {
		//the loading image is on screen, so load a real web page
		[self getScores];
	}
	else if (webViewLoadCounter > 1) {
		[thisWebView setUserInteractionEnabled:YES]; //allow the user to scroll things around now that the high scores are loaded
		
	}


}

- (void)webView:(UIWebView *)thisWebView didFailLoadWithError:(NSError *)error {
	if ([error code] != -999 && error != NULL) { //error -999 happens when the user clicks on something before it's done loading.
		
		UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Network Error" message:@"MultiTest was unable to load the page. Please try again later when you have a network connection."
													   delegate:self cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
		[alert show];
		[alert release];
		
	}		

} 

- (void) onExit {
	
}


-(void) getScores {

	NSString *urlBase = @"http://google.com";
	NSMutableURLRequest *request = [ [ NSMutableURLRequest alloc ] 
									initWithURL: [ NSURL URLWithString:urlBase ] ]; 
	
	[webView loadRequest:request];
	[request release];
}

- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex
{
	id junkSender;  //this is just here to make the backClicked method happy
	[self backClicked:junkSender];
}

-(void) backClicked:(id)sender {

	//reset the load counter - this is used to display the loading image when the layer is first entered
	webViewLoadCounter = 0;
	[webView stopLoading];
	webView.delegate = nil; //keep the webview from firing off any extra messages

	//remove items from the Superview...just to make sure they're gone
	[toolbar removeFromSuperview];
	[webView removeFromSuperview];
	[view removeFromSuperview];
	
	//reorient the director for the main game
	[[Director sharedDirector] setLandscape: YES];

	Scene *s2 = [Scene node];
	[s2 addChild: [LayerMenu node]];
	[[Director sharedDirector] replaceScene: [FadeTransition transitionWithDuration:0.5f scene:s2 withColorRGB:0xdffdfe]];
	
}

-(void)dealloc {
	[backButton release];
//	[toolbar release];
	[webView release];
	[view release];
	[super dealloc];
}

@end
